@@ -46,12 +46,13 @@ after_handle {
     if ($self->err_info) {
         $res = HTTP::Engine::Response->new;
         $res->code(500);
-        $res->body(
-            $self->err_info->as_html(
-                powered_by => $self->powerd_by,
-                ($self->renderer ? (renderer => $self->renderer) : ())
-            )
+
+        my $body = $self->err_info->as_html(
+            powered_by => $self->powerd_by,
+            ($self->renderer ? (renderer => $self->renderer) : ())
         );
+        utf8::downgrade($body) if utf8::is_utf8($body);
+        $res->body($body);
     }
 
     $res;
@@ -81,7 +82,7 @@ __END__
 
 =head1 NAME
 
-HTTP::Engine::Middleware::DebugScreen - documentation is TODO
+HTTP::Engine::Middleware::DebugScreen - dump stack-trace when die
 
 =head1 SYNOPSIS
 
@@ -94,6 +95,14 @@ HTTP::Engine::Middleware::DebugScreen - documentation is TODO
         }
     )->run();
 
+=head1 AUTHORS
+
+yappo
+
+kan
+
+and more?
+
 =head1 SEE ALSO
 
 L<Scope::Upper>, L<CGI::ExceptionManager::StackTrace>
